function Example_MaizeCoupling 
%
%
%
%
%
%
%
%

p = cell(4,1); % Automatically generated by Dicot.m and strongly modified... 
%-----------------------------------------
% Tap root
%-----------------------------------------
% Parameters editable by the GUI [mean, sd]
p{1}.r = [2, 0]; % Initial elongation rate (cm/day)
p{1}.a = [0.1, 0]; % Root radius (cm)  
p{1}.theta = [0.872665, 0]; % Insertion angle(rad)
p{1}.lb = [2, 0]; % Length of basal zone (cm)        
p{1}.la = [15, 0]; % Length of apical zone (cm)                    
p{1}.ln = [1, 0]; % Length between laterals (cm)
p{1}.nob = [30, 0]; % Maximal number of laterals (1)
% Additional parameters (predefined values, not altered by GUI)
p{1}.name = 'Tap root'; % Name of the root type
p{1}.color = [1, 0, 0]; % Color of the root (rgb)
p{1}.dx = 0.25; % Spatial resolution along root axis (cm)
p{1}.rlt = [Inf, 0]; % Maximal root life time [mean, std] (days)
p{1}.gf = 1; % Type of growth function (1: negative exponential, 2: linear)
% Preset by GUI 
p{1}.successor = [2, 1]; % Laterals [type,probability;type,probability;...]
%-----------------------------------------
% Laterals 
%-----------------------------------------
% Parameters editable by the GUI [mean, sd]
p{2}.r = [1.3, 0]; % Initial elongation rate (cm/day)
p{2}.a = [0.07, 0]; % Root radius (cm)  
p{2}.theta = [1.22173, 0]; % Insertion angle (rad)
p{2}.lb = [2, 0]; % Length of basal zone (cm)        
p{2}.la = [3, 0]; % Length of apical zone (cm)                    
p{2}.ln = [2, 0]; % Length between laterals (cm)
p{2}.nob = [7, 0]; % Maximal number of laterals (1)
% Additional parameters (predefined values)
p{2}.name = 'Lateral'; % Name of the root type
p{2}.color = [0, 1, 0]; % Color of the root (rgb)
p{2}.dx = 0.25; % Spatial resolution along root axis (cm)
p{2}.rlt = [Inf, 0]; % Maximal root life time [mean, std] (days)
p{2}.gf = 1; % Type of growth function (1: negative exponential, 2: linear)
% Preset by GUI 
p{2}.successor = []; % Laterals [type,probability;type,probability;...]
% -----------------------------------------
% Basal roots
% -----------------------------------------
% Parameters editable by the GUI [mean, sd]
p{4}.r = [2, 0]; % Initial elongation rate (cm/day)
p{4}.a = [0.1, 0]; % Root radius (cm)  
p{4}.theta = [1.309, 0]; % Insertion angle (rad)
p{4}.lb = [2, 0]; % Length of basal zone (cm)        
p{4}.la = [15, 0]; % Length of apical zone (cm)                    
p{4}.ln = [1, 0]; % Length between laterals (cm)
p{4}.nob = [30, 0]; % Maximal number of laterals (1)
% Additional parameters (predefined values)
p{4}.name = 'Basal root'; % Name of the root type
p{4}.color = [0.5, 0, 0.5]; % Color of the root (rgb)
p{4}.dx = 0.25; % Spatial resolution along root axis (cm)
p{4}.rlt = [Inf, 0]; % Maximal root life time [mean, std] (days)
p{4}.gf = 1; % Type of growth function (1: negative exponential, 2: linear)
% Preset by GUI 
p{4}.successor = [2, 1]; % Laterals [type,probability;type,probability;...]


%-----------------------------------------
% Monocot plant data (editable by the GUI)
%-----------------------------------------
plantingdepth = 3; % (cm)
% Basal roots
basal_first = [3, 0]; % First occurence [mean, std] (days)
basal_delay = [7, 0]; % Interim time [mean, std] (days)
basal_max = 100; % Maximal number of basal roots (1)
% Shoot borne roots
sb_first = [Inf, 0]; % Emergence time of first shoot borne root (days)
sb_delay = [3, 0]; % Time delay between the emergence of shoot borne roots (days)
sb_nCR = [11, 0]; % Number of shoot borne roots per root crown (1)
sb_delayRC = [33, 0]; % Time delay between the emergence of root crowns (days)
sb_dzRC = [1, 0]; % Distance between root crowns along the shoot (cm)


%----------------------------------------------
% COUPLING TO A STATIC SOIL PROPERTY
%----------------------------------------------

% 
% global rectangular mesh
%
global X
global Y 
global Z
width = 15; % cm
height = 40; % cm
x_ = linspace(-width, width, 30); % resolution 1 cm
y_ = linspace(-width, width, 30);
z_ = linspace(-height, 0, 40);
[X,Y,Z] = meshgrid(x_,y_,z_);

%
% soil property C 
%
global C;
x1 = [7,0,-10]; % postion of heterogeneity
r1 = 5; % 2*r1 is the width of the cube
C = conc_sphere(X,Y,Z,x1,r1,'box');
x2 = [-7,0,-10]; % control volume 
C2 = conc_sphere(X,Y,Z,x2,r1,'box'); 

%
% type of simulation
%

% plant soil interaction takes place using global variables
% 1. Root tropism (global variables X,Y,Z,C)
% 2. Scale root elongation (function handle sef)
% 3. Scale root branching probability (function handle sbpf)
% 4. Scale insertion angle (function handle saf)

tropism = true;  % turn off or on...
elongation = true; 
branching = false; 
angle = false; 

% 1   
if tropism 
    type = 3; % tropism
else 
    type = 1; % gravitropism
end
n = 1;
p{1}.tropism = [type, n, 0.2]; 
p{2}.tropism = [type, n, 0.4]; 
p{4}.tropism = [type, n, 0.2]; 

% 2
if elongation
    sef = @(x) my_sef(x); % defined at the end of the script
    p{1}.sef = sef;
    p{2}.sef = sef;
    p{4}.sef = sef;
end

% 3
if branching
    sbpf = @(x) my_sbpf(x); % defined at the end of the script
    p{1}.sbpf = sbpf;
    p{2}.sbpf = sbpf;
    p{4}.sbpf = sbpf;   
end

%4
if angle
    saf = @(x) my_saf(x); % defined at the end of the script
    p{1}.saf = saf;
    p{2}.saf = saf;
    p{4}.saf = saf;   
end



%-----------------------------------------
% Simulation
%-----------------------------------------

% Parameters (editable by the GUI)
simtime = 60;  % simulation time (days)

% Initialize RootBox
p = completeParameters(p); % it is possible to add a container geometry, see completeParameters  
set(0,'RecursionLimit',5000); % sometimes needed
str0 = createMonocotRS(plantingdepth,basal_first,basal_delay,basal_max,0.1,...
                sb_first,sb_delay,sb_nCR,sb_delayRC,sb_dzRC); % create initial string
p{5}.theta = 0;  % shootborne roots angle is already set in createMonocotRS
completeParameters(p); 

% Run N simulations
tic
N = 10; % number of simulation runs
for i = 1 : N
    fprintf('Simulation run %g\n',i);
    str{i} = applyRules(str0,simtime); % l-system string representing the root system
end
toc


%-----------------------------------------
% Visualisation of last simulation run
%-----------------------------------------

figure;
plotTubes(str{end});
% add visualisation of the soil heterogeneity and control volume
x1_ = (x1+[0,0,r1]);
dBox1 = @(p) distRhizotron(p-repmat(x1_,size(p,1),1),2*r1,2*r1,2*r1,0);
x2_ = (x2+[0,0,r1]);
dBox2 = @(p) distRhizotron(p-repmat(x2_,size(p,1),1),2*r1,2*r1,2*r1,0);
xx = linspace(-width,width,60); % finer mesh for visualization
yy = linspace(-width,width,60);
zz = linspace(0,-height,80);
plotDistFunc(dBox1,xx,yy,zz,'blue'); % heterogeneity
plotDistFunc(dBox2,xx,yy,zz,'red'); % control volume
hold on; slice(X,Y,Z,C,[],[0],[]); % show static soil 
xlabel('X (cm)');
ylabel('Y (cm)');
zlabel('Z (cm)');


%-----------------------------------------
% evaluation
%-----------------------------------------

% find root length and surface in the respective volumes
for i = 1  : length(str)    
  L = getDensity(str{i},[-inf,x_,inf],[-inf,y_,inf],[-inf,z_,inf],'l');
  S = getDensity(str{i},[-inf,x_,inf],[-inf,y_,inf],[-inf,z_,inf],'s'); 
  L = L(2:end-1,2:end-1,2:end-1); % remove first and last volume
  S = S(2:end-1,2:end-1,2:end-1);
  L = permute(L,[2,1,3]);
  S = permute(S,[2,1,3]);
  ind1 = C(1:end-1,1:end-1,1:end-1)+C(2:end,2:end,2:end)>0;
  l1(i) = sum(sum(sum(L(ind1))));
  s1(i) = sum(sum(sum(S(ind1))));
  ind2 = C2(1:end-1,1:end-1,1:end-1)+C2(2:end,2:end,2:end)>0;
  l2(i) = sum(sum(sum(L(ind2))));
  s2(i) = sum(sum(sum(S(ind2))));  
end
fprintf('Root length in blue volume is %g cm (+-%g) (soil heterogeneity) \n', mean(l1), std(l1));
fprintf('Root length in red volume is %g cm (+-%g) (control volume) \n', mean(l2), std(l2));

save('Example_MaizeCoupling'); % save local workspace





% returns zero everywhere but in a sphere around x with radius r, 
% where the value linearly increases towards the center
function C = conc_sphere(X,Y,Z,x,r, type)
if strcmp(type,'sphere')
    C = sqrt((X-x(1)).^2+(Y-x(2)).^2+(Z-x(3)).^2); % 2 norm
elseif strcmp(type,'box')
    C = max(max(abs(X-x(1)),abs(Y-x(2))),abs(Z-x(3))); % max norm
end
C(C>r)=r;
C = (r-C)./r;

% scale elongation function
function s = my_sef(p) % stop growing in blue box
global X Y Z C;
s = 1/(1+100*interp3(X,Y,Z,C,p.x(1),p.x(2),p.x(3))); % perform look up

% scale branichg probability
function s = my_sbpf(p)
global X Y Z C;
s = 1+interp3(X,Y,Z,C,p.x(1),p.x(2),p.x(3)); % perform look up

% scale insertion angle
function s = my_saf(p)
global X Y Z C;
s = 1+interp3(X,Y,Z,C,p.x(1),p.x(2),p.x(3)); % perform look up


