%
% Young oilseed rape root system architecture in a rhizotron
%
% Copyright 2008-2014 Daniel Leitner. See license.txt for details.
%
clear all;
set(0,'RecursionLimit',10000);

a0= 0.015; %[cm] 
a1= 0.012; %[cm]

% Tap root
p{1}.name='Tap root';
p{1}.r = 3; 
p{1}.lb = 0.7; 
p{1}.la = 1; 
p{1}.ln = [0.37, 0.25];
p{1}.nob = 540; 
p{1}.a = a0;   
p{1}.theta = 0;  
p{1}.color= [170/255,180/255,100/255];
p{1}.tropism = [1,5,20*pi/180]; 
p{1}.dx=0.25;
p{1}.successor = 2;

% 1st order lateral
p{2}.name = 'Lateral';
p{2}.r = 0.57;
p{2}.la = 200;
p{2}.a = a1;
p{2}.theta = [70*pi/180, 20*pi/180];
p{2}.color = [220/255,205/255,120/255];
p{2}.tropism = [1,1,20*pi/180]; 
p{2}.dx=0.25;

boxX=10; 
boxY=2; 
boxZ=38;
delta = 49/180*pi;
dfunc = @(p) distRhizotron(p,boxX,boxY,boxZ,delta);

p = completeParameters(p,dfunc);
%p = completeParameters(p);

% Simulation
n0=1; r0=3;
simtime = 20; % days
root = createRootSystem(0,0,zeros(n0,1),r0); 
str = applyRules(root,simtime);

% % visualize
plotTubes(str);
X = linspace(-6,6,100); 
Y = linspace(-6,6,100);
Z = linspace(-8,2,100);
plotDistFunc(dfunc,X,Y,Z); 
view(163,14);
xlabel('X');
ylabel('Y');
zlabel('Z');

% % Movie 
% mtime = 10; % seconds
% simtime = 20; % days
% fview = @(frame) view(163,14); 
% makeMovie('Rape.avi',root,simtime,mtime,fview); 


