function [I,J] = findTTACanditates(str,dt,s)
% findTTACanditates: find tip-tip anastomosis canditates
%
% str             hyphae tips 
% dt              time step, not used
% s               random seed 
%
% [I,J]           hyphae tip indices
%
%
% Copyright 2012-2014 Daniel Leitner & Andrea Schnepf. See license.txt for details.
%

I=[];
J=[];

HI = find(str(:,1)==400); % hyphae tip indices
X = str(HI+1,1:3); % tip positions
idd = str(HI,6); % infection identifier (unique per hyphal tree)

N=100;
if size(X,1)>N
    for k = 1 : ceil(size(X,1)/N)        
        tipIND{k} = 1+(k-1)*N : min(k*N,size(X,1));        
        offset(k) = 0 + (k-1)*N;
    end    
else
    tipIND{1} = 1:size(X,1);  
    offset = 0;
end


for k = 1 : length(tipIND)
    
    iddK = str(HI(tipIND{k}),6); % clever trick to avoid anastomosis within same branch
    dist = pdist2(iddK,idd);    
    PM = 1e-16./dist; % very small or inf [N*1:end]
    
    thresh = 0.01; % % cm %   TODO put into mycParameters
    
    XK = str(HI(tipIND{k})+1,1:3);
    dist  = pdist2(XK,X);
    dist  = (dist+PM)<thresh;
    [i,j] = find(dist);
    
    P = 1; % (unused) TODO put inot mycParameters
    iP = rand(s,size(i)) < P; % how do we want to model it? conceptual model? % dt should be in there
    i=i(iP);
    j=j(iP);
    
    i = i + offset(k); 
    
    I = [I; HI(i)];
    J = [J; HI(j)];

end
