function edges = getSusceptibles(str,x1,x2,time,ind,ct,s)
% getSusceptibles: uninfected segment indices suspectible to secondary infection
%
% str           list of l-system letters
% x1
% x2
% time
% ind           indices of segments within the l-system string
% ct            current simulation time
%
% edges:        array of segment (edge) indices that are susceptible
%
% See also: getNewInfection, getInfected, simulateMyc
%
%
% Copyright 2014-2015 Daniel Leitner & Andrea Schnepf. See license.txt for details.
%

global mycParameters;

m = mycParameters{1};

A = getGraph(str);
A = A+A'; % make undirected
len = sqrt(sum((x2-x1).^2,2)); % length of segments

edges = [];

if ~isempty(time)
    
    EI =  find(str(ind,6)==1 & str(ind,6)<100); % the edge indices of primary infected
                
    for i  = 1:length(EI)
        
        ei = EI(i); % current edge
        
        [I,J] = find(A==ei); % neighbouring  nodes
        i0 = I(1); % from i0 to j0 or vice versa
        j0 = J(1);     
        
        age = ct - time(ei);
        r = max(m.vi(1)+randn(s)*m.vi(2),0).*age; % radius that need to be infected since infection time

        edges = [edges, getPathsR(i0,i0,A,len,r,ind,str)];
    end
    
end

edges = unique(edges);





function edges = getPathsR(i0,oi,A,len,r,ind,str) % recursive function

edges=[];
J = find(A(i0,:)); % find neighbours

for j = 1 : length(J)
    
    j0 = J(j);
    
    if j0~=oi % dont go back
        
        ei = full(A(i0,j0));
        
        if r-len(ei)>=0 && str(ind(ei),5)<100   % not a hypha
            
            if str(ind(ei),6)==0 % add edge if uninfected
                edges = [edges, ei]; 
            end
                   
            % moving to from i0 to j0, i.e. i0 is old node
            edges = [edges, getPathsR(j0,i0,A,len,r-len(ei),ind,str)]; 
            
        end
        
    end
        
end
